@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -48,15 +48,19 @@ sub new {
 	my $self = { _shutter_root => shift, _mainwindow => shift, _appname => shift, _version => shift, _rev => shift, _pid => shift };
 
 	#vars
-	$self->{_debug_cparam}           	= FALSE;
-	$self->{_clear_cache}            	= FALSE;
-	$self->{_min_cparam}             	= FALSE;
-	$self->{_disable_systray_cparam} 	= FALSE;
+	$self->{_debug_cparam}              = FALSE;
+	$self->{_clear_cache}               = FALSE;
+	$self->{_min_cparam}                = FALSE;
+	$self->{_disable_systray_cparam}    = FALSE;
 	$self->{_exit_after_capture_cparam} = FALSE;
-	$self->{_start_with}             	= undef;
-	$self->{_start_with_extra}			= undef;
-	$self->{_profile_to_start_with}  	= undef;
-	$self->{_export_filename}			= undef;
+	$self->{_no_session_cparam}         = FALSE;
+	$self->{_start_with}                = undef;
+	$self->{_start_with_extra}          = undef;
+	$self->{_profile_to_start_with}     = undef;
+	$self->{_export_filename}           = undef;
+	$self->{_delay}						= undef;
+	$self->{_include_cursor}			= undef;
+	$self->{_remove_cursor}				= undef;
 
 	#Set LC_NUMERIC to C to prevent decimal commas (or anything else)
 	setlocale(LC_NUMERIC, "C");	
@@ -346,6 +350,19 @@ sub set_exit_after_capture {
 	return $self->{_exit_after_capture_cparam};
 }
 
+sub get_no_session {
+	my $self = shift;
+	return $self->{_no_session_cparam};
+}
+
+sub set_no_session {
+	my $self = shift;
+	if (@_) {
+		$self->{_no_session_cparam} = shift;
+	}
+	return $self->{_no_session_cparam};
+}
+
 sub get_start_with {
 	my $self = shift;
 	return ($self->{_start_with}, $self->{_start_with_extra});
@@ -386,6 +403,45 @@ sub set_export_filename {
 	return $self->{_export_filename};
 }
 
+sub get_include_cursor {
+	my $self = shift;
+	return $self->{_include_cursor};
+}
+
+sub set_include_cursor {
+	my $self = shift;
+	if (@_) {
+		$self->{_include_cursor} = shift;
+	}
+	return $self->{_include_cursor};
+}
+
+sub get_remove_cursor {
+	my $self = shift;
+	return $self->{_remove_cursor};
+}
+
+sub set_remove_cursor {
+	my $self = shift;
+	if (@_) {
+		$self->{_remove_cursor} = shift;
+	}
+	return $self->{_remove_cursor};
+}
+
+sub get_delay {
+	my $self = shift;
+	return $self->{_delay};
+}
+
+sub set_delay {
+	my $self = shift;
+	if (@_) {
+		$self->{_delay} = shift;
+	}
+	return $self->{_delay};
+}
+
 sub get_current_monitor {
 	my $self = shift;
 	my ( $window_at_pointer, $x, $y, $mask ) = Gtk2::Gdk->get_default_root_window->get_pointer;
