@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -58,16 +58,20 @@ sub get_options {
 		'web:s' => sub{ my ($web, $url) = @_; $self->{_sc}->set_start_with("web", $url); },
 		'r|redo' => sub{ $self->{_sc}->set_start_with("redoshot"); $self->{_sc}->set_min(TRUE); },
 		
-		'p|profile=s' => sub{ my ($p, $profile) = @_; $self->{_sc}->set_profile_to_start_with($profile); },		
-		'o|output=s' => sub{ my ($o, $output) = @_; $self->{_sc}->set_export_filename($output); },		
+		'p|profile=s' => sub{ my ($p, $profile) = @_; $self->{_sc}->set_profile_to_start_with($profile); },
+		'o|output=s' => sub{ my ($o, $output) = @_; $self->{_sc}->set_export_filename($output); },
+		'c|include_cursor' => sub{ $self->{_sc}->set_include_cursor(TRUE); },
+		'C|remove_cursor' => sub{ $self->{_sc}->set_remove_cursor(TRUE); },
+		'd|delay=s' => sub{ my ($d, $delay) = @_; $self->{_sc}->set_delay($delay); },
 		
 		'h|help' => sub{ pod2usage(-verbose => 1); },
-		'v|version' => sub{ print $self->{_sc}->get_version, " ", $self->{_sc}->get_rev, "\n"; exit; },		
-		'd|debug' => sub{ $self->{_sc}->set_debug(TRUE); },
+		'v|version' => sub{ print $self->{_sc}->get_version, " ", $self->{_sc}->get_rev, "\n"; exit; },
+		'debug' => sub{ $self->{_sc}->set_debug(TRUE); },
 		'clear_cache' => sub{ $self->{_sc}->set_clear_cache(TRUE); },
 		'min_at_startup' => sub{ $self->{_sc}->set_min(TRUE); },
 		'disable_systray' => sub{ $self->{_sc}->set_disable_systray(TRUE); },
 		'e|exit_after_capture' => sub{ $self->{_sc}->set_exit_after_capture(TRUE); },
+		'n|no_session' => sub{ $self->{_sc}->set_no_session(TRUE); },
 	);
 
 	#unknown value are passed through in @ARGV - might be filenames
