@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -39,7 +39,7 @@ use Glib qw/TRUE FALSE/;
 
 #--------------------------------------
 
-##################public subs##################
+
 sub new {
 	my $class = shift;
 
@@ -62,8 +62,6 @@ sub save_pixbuf_to_file {
 	my $filetype = shift;
 	my $quality = shift;
 
-	print "Saving file $filename, $filetype, $quality\n" if $self->{_common}->get_debug;
-
 	#gettext variable
 	my $d = $self->{_common}->get_gettext;
 
@@ -72,8 +70,8 @@ sub save_pixbuf_to_file {
 	$option = 1 unless defined $option;
 
 	#FIXME: NOT COVERED BY BINDINGS YET (we use Image::ExifTool instead)
-	#we rotate the pixbuf when saving to any other format than jpeg
-	unless ( $filetype eq 'jpeg' ) {
+	#we rotate the pixbuf when saving to any other format than jpeg (jpg)
+	unless ( $filetype eq 'jpeg' || $filetype eq 'jpg') {
 		if($option != 1){
 			$pixbuf = $self->{_lp}->auto_rotate($pixbuf);
 		}
@@ -81,25 +79,25 @@ sub save_pixbuf_to_file {
 
 	#we have two main ways of saving file
 	#when possible we try to use all supported formats of the gdk-pixbuf libs
-	#currently this is bmp, jpeg, png and ico (ico is not useful here)
+	#currently this is bmp, jpeg (jpg), png and ico (ico is not useful here)
 	my $imagemagick_result = undef;
-	if ( $filetype eq 'jpeg' ) {
+	if ( $filetype eq 'jpeg' || $filetype eq 'jpg' ) {
 		
 		#get quality value from settings if not set
-		unless($quality){
-			if(my $settings = $self->{_common}->get_globalsettings_object){
-				if(defined $settings->get_jpg_quality){
-					$quality = $settings->get_jpg_quality;
-				}else{
-					$quality = 90;
-				}
+		if(my $settings = $self->{_common}->get_globalsettings_object){
+			if(defined $settings->get_jpg_quality){
+				$quality = $settings->get_jpg_quality;
 			}else{
 				$quality = 90;
 			}
+		}else{
+			$quality = 90;
 		}
 		
+		print "Saving file $filename, $filetype, $quality\n" if $self->{_common}->get_debug;
+		
 		eval{
-			$pixbuf->save( $filename, $filetype, quality => $quality );
+			$pixbuf->save( $filename, 'jpeg', quality => $quality );
 			
 			#FIXME: NOT COVERED BY BINDINGS YET (we use Image::ExifTool instead)
 			#~ $pixbuf->set_option( 'orientation' => $option );
@@ -117,18 +115,18 @@ sub save_pixbuf_to_file {
 	} elsif ( $filetype eq 'png' ) {
 		
 		#get quality value from settings if not set
-		unless($quality){
-			if(my $settings = $self->{_common}->get_globalsettings_object){
-				if(defined $settings->get_png_quality){
-					$quality = $settings->get_png_quality;
-				}else{
-					$quality = 9;
-				}
+		if(my $settings = $self->{_common}->get_globalsettings_object){
+			if(defined $settings->get_png_quality){
+				$quality = $settings->get_png_quality;
 			}else{
 				$quality = 9;
 			}
+		}else{
+			$quality = 9;
 		}
 		
+		print "Saving file $filename, $filetype, $quality\n" if $self->{_common}->get_debug;
+		
 		eval{
 			$pixbuf->save( $filename, $filetype, "tEXt::Software" => "Shutter", compression => $quality );
 		};
@@ -138,6 +136,8 @@ sub save_pixbuf_to_file {
 		};
 	} elsif ( $filetype eq 'pdf' ) {	
 		
+		print "Saving file $filename, $filetype\n" if $self->{_common}->get_debug;
+		
 		#0.8? => 72 / 90 dpi		
     	my $surface = Cairo::PdfSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
     	my $cr = Cairo::Context->create($surface);
@@ -151,6 +151,8 @@ sub save_pixbuf_to_file {
 
 	} elsif ( $filetype eq 'ps' ) {
 		
+		print "Saving file $filename, $filetype\n" if $self->{_common}->get_debug;
+		
 		#0.8? => 72 / 90 dpi		
     	my $surface = Cairo::PsSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
     	my $cr = Cairo::Context->create($surface);
@@ -162,7 +164,9 @@ sub save_pixbuf_to_file {
 		undef $surface;
 		undef $cr;
 
-	} elsif ( $filetype eq 'svg' ) {	
+	} elsif ( $filetype eq 'svg' ) {
+		
+		print "Saving file $filename, $filetype\n" if $self->{_common}->get_debug;
 		
 		#0.8? => 72 / 90 dpi		
     	my $surface = Cairo::SvgSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
@@ -176,6 +180,9 @@ sub save_pixbuf_to_file {
 		undef $cr;
 	
 	} else  {
+		
+		print "Saving file $filename, $filetype, $quality (using fallback-mode)\n" if $self->{_common}->get_debug;
+		
 		#save pixbuf to tempfile
 		my ( $tmpfh, $tmpfilename ) = tempfile();
 		$tmpfilename .= '.png';
